@@ -80,6 +80,7 @@ have_constant "curl_version_sspi"
 have_constant "curl_version_conv"
 have_constant "curlproxy_http"
 have_constant "curlproxy_socks4"
+have_constant "curlproxy_socks4a"
 have_constant "curlproxy_socks5"
 have_constant "curlauth_basic"
 have_constant "curlauth_digest"
@@ -357,6 +358,8 @@ have_constant "curlopt_gssapi_delegation"
 have_constant "curlgssapi_delegation_policy_flag"
 have_constant "curlgssapi_delegation_flag"
 
+have_constant "CURLM_ADDED_ALREADY"
+
 if try_compile('int main() { return 0; }','-Wall')
   $CFLAGS << ' -Wall'
 end
@@ -372,23 +375,6 @@ def test_for(name, const, src)
     end
   end
 end
-test_for("Ruby 1.9 Hash", "RUBY19_HASH", %{
-  #include <ruby.h>
-  int main() {
-    VALUE hash = rb_hash_new();
-    if( RHASH(hash)->ntbl->num_entries ) {
-      return 0;
-    }
-    return 1;
-  }
-})
-test_for("Ruby 1.9 st.h", "RUBY19_ST_H", %{
-  #include <ruby.h>
-  #include <ruby/st.h>
-  int main() {
-    return 0;
-  }
-})
 
 test_for("curl_easy_escape", "CURL_EASY_ESCAPE", %{
   #include <curl/curl.h>
@@ -400,6 +386,7 @@ test_for("curl_easy_escape", "CURL_EASY_ESCAPE", %{
 })
 
 have_func('rb_thread_blocking_region')
+have_header('ruby/thread.h') && have_func('rb_thread_call_without_gvl', 'ruby/thread.h')
 
 create_header('curb_config.h')
 create_makefile('curb_core')
